@@ -1,23 +1,22 @@
-/* test file for mpc_add_ui.
+/* tadd_ui -- test file for mpc_add_ui.
 
-Copyright (C) INRIA, 2008, 2010
+Copyright (C) 2008, 2010, 2012 INRIA
 
-This file is part of the MPC Library.
+This file is part of GNU MPC.
 
-The MPC Library is free software; you can redistribute it and/or modify
-it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+GNU MPC is free software; you can redistribute it and/or modify it under
+the terms of the GNU Lesser General Public License as published by the
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-The MPC Library is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-License for more details.
+GNU MPC is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for
+more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPC Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-MA 02111-1307, USA. */
+along with this program. If not, see http://www.gnu.org/licenses/ .
+*/
 
 #include <stdlib.h>
 #include "mpc-tests.h"
@@ -42,7 +41,7 @@ check_ternary_value (void)
         }
 
       mpc_set_ui (z, 1, MPC_RNDNN);
-      mpc_mul_2exp (z, z, (unsigned long int) prec, MPC_RNDNN);
+      mpc_mul_2ui (z, z, (unsigned long int) prec, MPC_RNDNN);
       if (mpc_add_ui (z, z, 1, MPC_RNDNN) == 0)
         {
           printf ("Error in mpc_add_ui: 2^prec+1 cannot be exact\n");
